@@ -257,7 +257,7 @@ res
 ###################################################
 allele2 <- res$map[["allele.2"]]
 ## number of alternate alleles per variant
-unique(elementLengths(allele2))
+unique(elementNROWS(allele2))
 
 
 ###################################################
