@@ -1,7 +1,7 @@
 test_ScanVcfParam_which <- function()
 {
-    which <- RangesList(seq1=IRanges(1000, 2000), 
-                        seq2=IRanges(c(100, 1000), c(1000, 2000)))
+    which <- IRangesList(seq1=IRanges(1000, 2000), 
+                         seq2=IRanges(c(100, 1000), c(1000, 2000)))
     svp <- ScanVcfParam(which=which)
     checkIdentical(which, vcfWhich(svp))
     checkException(vcfWhich(svp) <- DataFrame(), silent=TRUE)
